procedure

Attribute Macro procedure 

#[procedure]
Creates a procedure handler from an async function.

This macro transforms an async function into a procedure handler that can be registered with the procedure call system. The function must take either one or two parameters:

  • A state parameter (optional)
  • A procedure parameter

Examples

#[procedure]
async fn handle_procedure(proc: MyProcedureRequest) -> Result {
    // Handle the procedure
    Ok(MyProcedureResponse)
}